/* g++ -DLINUX examples/adc_example.cpp  -lcc-aux2 -pthread -ldl */
#include <Adc.h>
#include <assert.h>
#include <iomanip>
#include <iostream>

using namespace std;
using namespace CrossControl;

void output_voltage(
                    ADCHANDLE pAdc,
                    char const* description,
                    CrossControl::VoltageEnum selection)
{
  if(!pAdc)
    return;

  CrossControl::eErr err;
  double voltage;

  //! [Calling Adc_getVoltage]
  err = Adc_getVoltage(pAdc, selection, &voltage);
  if (err == CrossControl::ERR_SUCCESS)
  {
    cout << left << setw(7) << description << ": " <<
      fixed << setprecision(2) << voltage << "V" << endl;
  }
  else if (err == CrossControl::ERR_NOT_SUPPORTED)
  {
    /* Don't print anything */
  }
  else
  {
    cout << left << setw(7) << description << ": " <<
      fixed << setprecision(2) << CrossControl::GetErrorStringA(err) << endl;
  }
  //! [Calling Adc_getVoltage]
}


int main(void)
{
  //! [Calling Adc_release]
  //! [Calling GetAdc]
  ADCHANDLE pAdc = ::GetAdc();
  assert(pAdc);

  output_voltage (pAdc, "24VIN", CrossControl::VOLTAGE_24VIN);
  output_voltage (pAdc, "24V",   CrossControl::VOLTAGE_24V);
  output_voltage (pAdc, "12V",   CrossControl::VOLTAGE_12V);
  output_voltage (pAdc, "12VID", CrossControl::VOLTAGE_12VID);
  output_voltage (pAdc, "5V",    CrossControl::VOLTAGE_5V);
  output_voltage (pAdc, "3V3",   CrossControl::VOLTAGE_3V3);
  output_voltage (pAdc, "VTFT",  CrossControl::VOLTAGE_VTFT);
  output_voltage (pAdc, "5VSTB", CrossControl::VOLTAGE_5VSTB);
  output_voltage (pAdc, "1V9",   CrossControl::VOLTAGE_1V9);
  output_voltage (pAdc, "1V8",   CrossControl::VOLTAGE_1V8);
  output_voltage (pAdc, "1V5",   CrossControl::VOLTAGE_1V5);
  output_voltage (pAdc, "1V2",   CrossControl::VOLTAGE_1V2);
  output_voltage (pAdc, "1V05",  CrossControl::VOLTAGE_1V05);
  output_voltage (pAdc, "1V0",   CrossControl::VOLTAGE_1V0);
  output_voltage (pAdc, "0V9",   CrossControl::VOLTAGE_0V9);
  output_voltage (pAdc, "VREF_INT",   CrossControl::VOLTAGE_VREF_INT);
  output_voltage (pAdc, "24V_BACKUP", CrossControl::VOLTAGE_24V_BACKUP);
  output_voltage (pAdc, "2V5",        CrossControl::VOLTAGE_2V5);
  output_voltage (pAdc, "1V1",        CrossControl::VOLTAGE_1V1);
  output_voltage (pAdc, "1V3_PER",    CrossControl::VOLTAGE_1V3_PER);
  output_voltage (pAdc, "1V3_VDDA",   CrossControl::VOLTAGE_1V3_VDDA);
  output_voltage (pAdc, "3V3 STBY",   CrossControl::VOLTAGE_3V3STBY);
  output_voltage (pAdc, "VPMIC",      CrossControl::VOLTAGE_VPMIC);
  output_voltage (pAdc, "VMAIN",      CrossControl::VOLTAGE_VMAIN);

  Adc_release(pAdc);
  //! [Calling GetAdc]
  //! [Calling Adc_release]
}
