/* g++ -DLINUX examples/battery_example.cpp  -lcc-aux -pthread -ldl */
#include <Battery.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>
#include <string.h>

using namespace std;
using namespace CrossControl;

void readBatteryInfo(BATTERYHANDLE pBattery)
{
  eErr error;
  bool bpresent;
  std::string input;

  if(!pBattery)
    return;

  //! [Calling isBatteryPresent]
  error = Battery_isBatteryPresent(pBattery, &bpresent);

  if(error != ERR_SUCCESS)
  {
    cout << "isBatteryPresent: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    if(bpresent)
    {
      cout << "Battery is present. Testing functionality... " << std::endl;
    }
    else
    {
      cout << "Battery is NOT present." << std::endl;    
    }
  }
  //! [Calling isBatteryPresent]

  //! [Calling getBatteryChargingStatus]
  ChargingStatus cs;
  error = Battery_getBatteryChargingStatus(pBattery, &cs);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getBatteryChargingStatus: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getBatteryChargingStatus: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    switch(cs)
    {
    case ChargingStatus_NoCharge:
      cout << "getBatteryChargingStatus: Battery is not being charged" << std::endl;
      break;
    case ChargingStatus_Charging:
      cout << "getBatteryChargingStatus: Battery is being charged" << std::endl;
      break;
    case ChargingStatus_FullyCharged: 
      cout << "getBatteryChargingStatus: Battery is fully charged" << std::endl;
      break;
    case ChargingStatus_TempLow:
      cout << "getBatteryChargingStatus: Temperature is too low to charge the battery" << std::endl;
      break;
    case ChargingStatus_TempHigh:   
      cout << "getBatteryChargingStatus: Temperature is too high to charge the battery" << std::endl;
      break;
    case ChargingStatus_Unknown:
      cout << "getBatteryChargingStatus: ChargingStatus_Unknown" << std::endl;
      break;
    default:
      cout << "getBatteryChargingStatus: invalid return value" << std::endl;
      break;
    }
  }
  //! [Calling getBatteryChargingStatus]


  //! [Calling getBatteryHWversion]
  char buf[255];
  error = Battery_getBatteryHWversion(pBattery, buf, sizeof(buf));
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getBatteryHWversion: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getBatteryHWversion: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getBatteryHWversion: " << buf << std::endl;
  }
  //! [Calling getBatteryHWversion]

  //! [Calling getBatterySerial]
  error = Battery_getBatterySerial(pBattery,buf, sizeof(buf));
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getBatterySerial: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getBatterySerial: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getBatterySerial: " << buf << std::endl;
  }
  //! [Calling getBatterySerial]


  //! [Calling getBatterySwVersion]
  unsigned short major;
  unsigned short minor;
  unsigned short release;
  unsigned short build;
  error = Battery_getBatterySwVersion(pBattery, &major, &minor, &release, &build);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getBatterySwVersion: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getBatterySwVersion: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getBatterySwVersion: v" << major << "." << minor << "." << release << "." << build << std::endl;
  }
  //! [Calling getBatterySwVersion]


  //! [Calling getBatteryTemp]
  short temp;
  error = Battery_getBatteryTemp(pBattery, &temp);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getBatteryTemp: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getBatteryTemp: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getBatteryTemp: " << temp << " deg C" << std::endl;
  }
  //! [Calling getBatteryTemp]


  //! [Calling getBatteryVoltageStatus]

  unsigned char s;
  error = Battery_getBatteryVoltageStatus(pBattery, &s);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getBatteryVoltageStatus: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getBatteryVoltageStatus: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getBatteryVoltageStatus: " << (int)s << " %" << std::endl;
  }
  //! [Calling getBatteryVoltageStatus]


  //! [Calling getHwErrorStatus]
  ErrorStatus es;
  error = Battery_getHwErrorStatus(pBattery, &es);

  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getHwErrorStatus: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getHwErrorStatus: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    switch(es)
    {
    case ErrorStatus_NoError:
      cout << "getHwErrorStatus: " << "Battery reports no HW errors" << std::endl;
      break;
    case ErrorStatus_ThermistorTempSensor:
      cout << "getHwErrorStatus: " << "Battery error! The thermistor temp sensor is not working" << std::endl;
      break;
    case ErrorStatus_SecondaryTempSensor:
      cout << "getHwErrorStatus: " << "Battery error! The secondary temp sensor is not working" << std::endl;
      break;
    case ErrorStatus_ChargeFail:
      cout << "getHwErrorStatus: " << "Battery error! Charging failed" << std::endl;
      break;
    case ErrorStatus_Overcurrent:
      cout << "getHwErrorStatus: " << "Battery error! Overcurrent detected" << std::endl;
      break;
    case ErrorStatus_Init:
      cout << "getHwErrorStatus: " << "Battery error! Battery not initiated" << std::endl;
      break;
    default: 
      cout << "getHwErrorStatus: " << "invalid return value" << std::endl;
      break;
    }	
  }
  //! [Calling getHwErrorStatus]


  //! [Calling getMinMaxTemp]
  short max;
  error = Battery_getMinMaxTemp(pBattery, &temp, &max);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getMinMaxTemp: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getMinMaxTemp: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getMinMaxTemp: MinTemp:" << temp << ", MaxTemp: " << max << std::endl;
  }
  //! [Calling getMinMaxTemp]


  //! [Calling getPowerSource]
  PowerSource ps;
  error = Battery_getPowerSource(pBattery, &ps);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getPowerSource: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getPowerSource: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    if(ps == PowerSource_Battery)
      cout << "getPowerSource: Power source: Battery" << std::endl;
    else
      cout << "getPowerSource: Power source: External Power" << std::endl;
  }
  //! [Calling getPowerSource]


  //! [Calling getTimer]
  BatteryTimerType times;
  memset(&times, 0, sizeof(times));
  error = Battery_getTimer(pBattery, &times);
  if(error == ERR_NOT_SUPPORTED && !bpresent)
  {
    cout << "getTimer: " << GetErrorStringA(error) << " - battery is not present!" << std::endl;
  } 
  else if(error != ERR_SUCCESS)
  {
    cout << "getTimer: " << GetErrorStringA(error) << std::endl;
  }
  else
  {
    cout << "getTimer: " << std::endl;
    cout << "Total run time on main power=" << times.TotRunTimeMain*60 << " min(s)" << std::endl
      << "Total run time on battery power=" << times.TotRunTimeBattery*60 << " min(s)" << std::endl
      << "Total run time below -20C=" << times.RunTime_m20 << " min(s)" << std::endl
      << "Total run time -20-0C=" << times.RunTime_m20_0 << " min(s)" << std::endl
      << "Total run time 0-40C=" << times.RunTime_0_40 << " min(s)" << std::endl
      << "Total run time 40-60C=" << times.RunTime_40_60 << " min(s)" << std::endl
      << "Total run time 60-70C=" << times.RunTime_60_70 << " min(s)" << std::endl
      << "Total run time 70-80C=" << times.RunTime_70_80 << " min(s)" << std::endl
      << "Total run time above 80C=" << times.RunTime_Above80 << " min(s)" << std::endl;
  }
  //! [Calling getTimer]

}

int main(void)
{
  //! [Calling Battery_release]
  //! [Calling GetBattery]
  BATTERYHANDLE pBattery = ::GetBattery();
  assert(pBattery);

  readBatteryInfo(pBattery);

  Battery_release(pBattery);
  //! [Calling GetBattery]
  //! [Calling Battery_release]
}
