/* g++ -DLINUX examples/buzzer_example.cpp  -lcc-aux2 -pthread -ldl */
#include <Buzzer.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>

using namespace std;
using namespace CrossControl;

// 'Beep' implementation
void MyBeep(BUZZERHANDLE pBuzzer, unsigned short freq, int duration)
{
  CrossControl::eErr err;

  if(!pBuzzer)
    return;
  //! [Calling Buzzer_setFrequency]
  //! [Calling Buzzer_buzze]
  err = Buzzer_setFrequency(pBuzzer, freq);
  if(err != ERR_SUCCESS) 
  {
    cout << "Error(" << err << ") in function setFrequency: " << GetErrorStringA(err) << endl;
  } 
  else
  {
    err =  Buzzer_buzze(pBuzzer, duration, true);
    if(err != ERR_SUCCESS) 
    {
      cout << "Error(" << err << ") in function buzze: " << GetErrorStringA(err) << endl;
    } 
    //! [Calling Buzzer_buzze]
    //! [Calling Buzzer_setFrequency]
  }  
}


void play_beeps(BUZZERHANDLE pBuzzer)
{
  if(!pBuzzer)
    return;

  CrossControl::eErr err;
  unsigned short vol;

  //! [Calling Buzzer_getVolume]
  err = Buzzer_getVolume( pBuzzer, &vol);
  if(err == ERR_SUCCESS)
  {
    cout << "Buzzer volume was: " << vol << endl;
  }
  else
  {
    cout << "Error(" << err << ") in function getVolume: " << GetErrorStringA(err) << endl;
    vol = 40;
  } 
  //! [Calling Buzzer_getVolume]

  //! [Calling Buzzer_setVolume]
  err = Buzzer_setVolume( pBuzzer, 20);
  if(err == ERR_SUCCESS)
  {
    cout << "Buzzer volume set to 20" << endl;
  }
  else
  {
    cout << "Error(" << err << ") in function setVolume: " << GetErrorStringA(err) << endl;
  } 
  //! [Calling Buzzer_setVolume]

  MyBeep(pBuzzer, 1000, 500); 
  err = Buzzer_setVolume( pBuzzer, 40);
  MyBeep(pBuzzer, 900, 500); 
  err = Buzzer_setVolume( pBuzzer, 51);
  MyBeep(pBuzzer, 700, 500); 

  cout << "Restoring volume: " << vol << endl;
  err = Buzzer_setVolume( pBuzzer, vol);
}

int main(void)
{
  //! [Calling Buzzer_release]
  //! [Calling GetBuzzer]
  BUZZERHANDLE pBuzzer = ::GetBuzzer();
  assert(pBuzzer);

  play_beeps(pBuzzer);

  Buzzer_release(pBuzzer);
  //! [Calling GetBuzzer]
  //! [Calling Buzzer_release]
}
