/* g++ -DLINUX examples/diagnostic_example.cpp  -lcc-aux2 -pthread -ldl */
#include <Diagnostic.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>
#include <stdio.h>

using namespace std;
using namespace CrossControl;


void printStringTime(eErr err, const char* text, unsigned long value)
{
  unsigned long rest;
  unsigned day, hour;

  day = value / 1440;
  rest = value % 1440;
  hour = rest / 60;
  rest = value % 60;

  if(err == ERR_SUCCESS)
  {
    printf("%s: %d min (%d days, %dh, %dmin)\n", text, value, day, hour, rest);
  }  
  else
  {
    printf("%s: Error(%d) %s\n", text, err, CrossControl::GetErrorStringA(err)); 
  }
}

void printString(eErr err, const char* text, signed short value, const char* text2)
{
  if(err == ERR_SUCCESS)
  {
    printf("%s: %d %s\n", text, value, text2);
  }  
  else
  {
    printf("%s: Error(%d) %s\n", text, err, CrossControl::GetErrorStringA(err)); 
  }
}

void diagnostic_example(DIAGNOSTICHANDLE pDiagnostic)
{
  CrossControl::eErr err;
  TimerType tt;
  signed short sValue, sValue2;

  if(!pDiagnostic)
    return;

  //! [Calling Diagnostic_getSSTemp]
  err = Diagnostic_getSSTemp(pDiagnostic, &sValue);
  printString(err, "Main board (SS) temp", sValue, "deg C");
  //! [Calling Diagnostic_getSSTemp]

  //! [Calling Diagnostic_getTimer]
  err = Diagnostic_getTimer(pDiagnostic, &tt);
  printStringTime(err, "Total run time", tt.TotRunTime);
  printStringTime(err, "Total suspend time", tt.TotSuspTime);
  printStringTime(err, "Total heat time", tt.TotHeatTime);
  printStringTime(err, "Total run time 40-60 deg C", tt.RunTime40_60);
  printStringTime(err, "Total run time 60-70 deg C", tt.RunTime60_70);
  printStringTime(err, "Total run time 70-80 deg C", tt.RunTime70_80);
  printStringTime(err, "Total run time above 80 deg C", tt.Above80RunTime);
  //! [Calling Diagnostic_getTimer]

  //! [Calling Diagnostic_getMinMaxTemp]
  err = Diagnostic_getMinMaxTemp(pDiagnostic, &sValue, &sValue2);
  printString(err, "Minimum temp", sValue, "deg C");
  printString(err, "Maximum temp", sValue2, "deg C");
  //! [Calling Diagnostic_getMinMaxTemp]
}

int main(void)
{
  //! [Calling Diagnostic_release]
  //! [Calling GetDiagnostic]
  DIAGNOSTICHANDLE pDiagnostic = ::GetDiagnostic();
  assert(pDiagnostic);

  diagnostic_example(pDiagnostic);

  Diagnostic_release(pDiagnostic);
  //! [Calling GetDiagnostic]
  //! [Calling Diagnostic_release]
}
