/* g++ -DLINUX examples/frontled_example.cpp  -lcc-aux2 -pthread -ldl */
#include <FrontLED.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>

using namespace std;
using namespace CrossControl;

void led_example(FRONTLEDHANDLE pFrontLED)
{
  CrossControl::eErr err;
  double freq;
  unsigned char dutycycle, red, green, blue;

  if(!pFrontLED)
    return;

  //
  // Get current settings for the LED
  //

  //! [Calling FrontLED_getSignal]
  err = FrontLED_getSignal(pFrontLED, &freq, &dutycycle);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function getSignal: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_getSignal]

  //! [Calling FrontLED_getColor]
  err = FrontLED_getColor(pFrontLED, &red, &green, &blue);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function getColor: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_getColor]


  //
  // Set LED blinking 2Hz red
  //

  cout << "Setting 2Hz red blink..." << endl;

  //! [Calling FrontLED_setOffTime]
  err = FrontLED_setOffTime(pFrontLED, 25);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function setOfftime: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_setOffTime]

  //! [Calling FrontLED_setOnTime]
  err = FrontLED_setOnTime(pFrontLED, 25);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function setOnTime: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_setOnTime]

  //! [Calling FrontLED_setStandardColor]
  err = FrontLED_setStandardColor(pFrontLED, RED);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function setStandardColor: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_setStandardColor]

  cin.sync();
  cout << endl << "Press Enter to restore the LED..." << endl;
  cin.get();

  //
  // Restore settings
  //

  //! [Calling FrontLED_setSignal]
  err = FrontLED_setSignal(pFrontLED, freq, dutycycle);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function setSignal: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_setSignal]

  //! [Calling FrontLED_setColor]
  err = FrontLED_setColor(pFrontLED, red, green, blue);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function setColor: " << GetErrorStringA(err) << endl;
  }
  //! [Calling FrontLED_setColor]



}


int main(void)
{
  //! [Calling FrontLED_release]
  //! [Calling GetFrontLED]
  FRONTLEDHANDLE pFrontLED = ::GetFrontLED();
  assert(pFrontLED);

  led_example(pFrontLED);

  FrontLED_release(pFrontLED);
  //! [Calling GetFrontLED]
  //! [Calling FrontLED_release]
}
