/* g++ -DLINUX examples/power_example.cpp  -lcc-aux2 -pthread -ldl */
#include <Power.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>

using namespace std;
using namespace CrossControl;

void power_example(POWERHANDLE pPower)
{
  CrossControl::eErr err;
  unsigned char value;
  CCStatus status;

  //! [Calling Power_getBLPowerStatus]
  err = Power_getBLPowerStatus(pPower, &status);
  if(err == ERR_SUCCESS)
  {
    cout << "Backlight power is " << ((status == Enabled)? "ON" : "OFF") << endl;
  }
  else 
  {
    cout << "Error(" << err << ") in function Power_getBLPowerStatus: " << GetErrorStringA(err) << endl;
  }
  //! [Calling Power_getBLPowerStatus]


  //! [Calling Power_getVideoPowerStatus]
  err = Power_getVideoPowerStatus(pPower, &value);
  if(err == ERR_SUCCESS)
  {
    cout << "Video power status: " << endl;
    cout << "Video1: " << ((value & 0x01)? "ON" : "OFF") << endl;
    cout << "Video2: " << ((value & 0x02)? "ON" : "OFF") << endl;
    cout << "Video3: " << ((value & 0x04)? "ON" : "OFF") << endl;
    cout << "Video4: " << ((value & 0x08)? "ON" : "OFF") << endl;   
  }
  else
  {
    cout << "Error(" << err << ") in function Power_getVideoPowerStatus: " << GetErrorStringA(err) << endl;
  }
  //! [Calling Power_getVideoPowerStatus]


  //! [Calling Power_setBLPowerStatus]
  cout << "Blinking backlight... " << endl;
  cin.sync();
  cout << endl << "Press Enter to to turn off the Backlight and then Enter to turn it on again..." << endl;
  cin.get();
  err = Power_setBLPowerStatus(pPower, Disabled);
  cin.sync();
  cin.get();
  err = Power_setBLPowerStatus(pPower, Enabled);
  if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function Power_setBLPowerStatus: " << GetErrorStringA(err) << endl;
  }
  //! [Calling Power_setBLPowerStatus]


  //! [Calling Power_getCanOCDStatus]
  cout << "Checking overcurrent status... " << endl;
  OCDStatus ocdstatus;
  err = Power_getCanOCDStatus(pPower, &ocdstatus);
  if(err == ERR_NOT_SUPPORTED)
  {
    cout << "Not supported." << endl;
  }
  else if(err != ERR_SUCCESS)
  {
    cout << "Error(" << err << ") in function Power_getCanOCDStatus: " << GetErrorStringA(err) << endl;
  }
  else
  {
    cout << "Power_getCanOCDStatus: Can OCD status is: ";
    switch(ocdstatus)
    {
    case OCD_OK: cout << "OCD_OK" << std::endl; break;
    case OCD_OC: cout << "OCD_OC" << std::endl; break;
    case OCD_POWER_OFF: cout << "OCD_POWER_OFF" << std::endl; break;
    default: cout << "ERROR" <<  std::endl; break;
    }
  }
  //! [Calling Power_getCanOCDStatus]

  //! [Calling Power_getVideoOCDStatus]
  err = Power_getVideoOCDStatus(pPower, &ocdstatus);
  if(err == ERR_NOT_SUPPORTED)
  {
    /* Don't print anything */
  }
  else 
    if(err != ERR_SUCCESS)
    {
      cout << "Error(" << err << ") in function Power_getVideoOCDStatus: " << GetErrorStringA(err) << endl;
    }
    else
    {
      cout << "Power_getVideoOCDStatus: Video OCD status is: ";
      switch(ocdstatus)
      {
      case OCD_OK: cout << "OCD_OK" << std::endl; break;
      case OCD_OC: cout << "OCD_OC" << std::endl; break;
      case OCD_POWER_OFF: cout << "OCD_POWER_OFF" << std::endl; break;
      default: cout << "ERROR" <<  std::endl; break;
      }
    }
    //! [Calling Power_getVideoOCDStatus]

}


int main(void)
{
  //! [Calling Power_release]
  //! [Calling GetPower]
  POWERHANDLE pPower = ::GetPower();
  assert(pPower);

  power_example(pPower);

  Power_release(pPower);
  //! [Calling GetPower]
  //! [Calling Power_release]
}
