/* g++ -DLINUX examples/pwmout_example.cpp  -lcc-aux2 -pthread -ldl */
#include <PWMOut.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>

using namespace std;
using namespace CrossControl;


void pwmout_example(PWMOUTHANDLE pPwmOut)
{
  CrossControl::eErr err;


  if(!pPwmOut)
    return;

  //! [Calling PWMOut_setPWMOutputChannelDutyCycle]
  err = PWMOut_setPWMOutputChannelDutyCycle(pPwmOut, 1, 50);
  if(err != ERR_SUCCESS)
  {
    cout << "setPWMOutputChannelDutyCycle: " << GetErrorStringA(err) << std::endl;
  }
  else
  {
    cout << "setPWMOutputChannelDutyCycle: channel 1 set to 50% duty cycle" << std::endl;
  }
  //! [Calling PWMOut_setPWMOutputChannelDutyCycle]

  //! [Calling PWMOut_setPWMOutputChannelFrequency]
  err = PWMOut_setPWMOutputChannelFrequency(pPwmOut, 1, (float)100.0);
  if(err != ERR_SUCCESS)
  {
    cout << "PWMOut_setPWMOutputChannelFrequency: " << GetErrorStringA(err) << std::endl;
  }
  else
  {
    cout << "PWMOut_setPWMOutputChannelFrequency: channel 1 set to 100Hz" << std::endl;
  }
  //! [Calling PWMOut_setPWMOutputChannelFrequency]


  //! [Calling PWMOut_getPWMOutputChannelDutyCycle]
  unsigned char duty;
  err = PWMOut_getPWMOutputChannelDutyCycle(pPwmOut, 1, &duty);
  if(err != ERR_SUCCESS)
  {
    cout << "PWMOut_getPWMOutputChannelDutyCycle: " << GetErrorStringA(err) << std::endl;
  }
  else
  {
    cout << "PWMOut_getPWMOutputChannelDutyCycle channel 1: " << (int)duty << "% duty cycle" << std::endl;
  }
  //! [Calling PWMOut_getPWMOutputChannelDutyCycle]


  //! [Calling PWMOut_getPWMOutputChannelFrequency]
  float frequency;
  err = PWMOut_getPWMOutputChannelFrequency(pPwmOut, 1, &frequency);
  if(err != ERR_SUCCESS)
  {
    cout << "PWMOut_getPWMOutputChannelFrequency: " << GetErrorStringA(err) << std::endl;
  }
  else
  {
    cout << "PWMOut_getPWMOutputChannelFrequency channel 1: " << std::fixed << frequency << "Hz" << std::endl;
  }
  //! [Calling PWMOut_getPWMOutputChannelFrequency]


  //! [Calling PWMOut_getPWMOutputStatus]
  unsigned char status;
  err = PWMOut_getPWMOutputStatus(pPwmOut, &status);
  if(err != ERR_SUCCESS)
  {
    cout << "PWMOut_getPWMOutputStatus: " << GetErrorStringA(err) << std::endl;
  }
  else
  {
    if(status & 0x01)
      cout << "PWMOut_getPWMOutputStatus: Status Not OK for channel 1" << std::endl;
    if(status & 0x02)
      cout << "PWMOut_getPWMOutputStatus: Status Not OK for channel 2" << std::endl;
    if((status & 0x03) == 0)
      cout << "PWMOut_getPWMOutputStatus: Status OK for both channels" << std::endl;
  }
  //! [Calling PWMOut_getPWMOutputStatus]


  //! [Calling PWMOut_setPWMOutOff]
  err = PWMOut_setPWMOutOff(pPwmOut, 1);
  if(err != ERR_SUCCESS)
  {
    cout << "PWMOut_setPWMOutOff: " << GetErrorStringA(err) << std::endl;
  }
  else
  {
    cout << "PWMOut_setPWMOutOff channel 1 turned off" << std::endl;
  }
  //! [Calling PWMOut_setPWMOutOff]

}



int main(void)
{
  //! [Calling PWMOut_release]
  //! [Calling GetPWMOut]
  PWMOUTHANDLE pPwmOut = ::GetPWMOut();
  assert(pPwmOut);

  pwmout_example(pPwmOut);

  PWMOut_release(pPwmOut);
  //! [Calling GetPWMOut]
  //! [Calling PWMOut_release]
}
