/* g++ -DLINUX examples/smart_example.cpp  -lcc-aux -pthread -ldl */
#include <assert.h>
#include <Smart.h>
#include <iostream>
#include <time.h>

using namespace std;
using namespace CrossControl;

void show_card_data(SMARTHANDLE pSmart)
{
  if(!pSmart)
    return;

  eErr err;

  cout << "Smart class example:" << endl;


  //! [Calling getDeviceSerial]
  char serial[21];
  err = Smart_getDeviceSerial (pSmart, serial, sizeof(serial));
  if (ERR_SUCCESS == err)
  {
    cout << "Device serial number: " << serial << endl;
  }
  else
  {
    cout << "Error(" << err << ") in function getDeviceSerial: " << GetErrorStringA(err) << endl;
  }
  //! [Calling getDeviceSerial]

 
  //! [Calling getRemainingLifeTime]
  unsigned char life;
  err = Smart_getRemainingLifeTime (pSmart, &life);
  if (ERR_SUCCESS == err)
  {
    cout << "Estimated remaining lifetime: " << (int)life << "%" << endl;
  }
  else
  {
    cout << "Error(" << err << ") in function getRemainingLifeTime: " << GetErrorStringA(err) << endl;
  }
  //! [Calling getRemainingLifeTime]

  //! [Calling getInitialTime]
  time_t initialTime;
  struct tm * timeinfo;
  err = Smart_getInitialTime (pSmart, &initialTime);
  if (ERR_SUCCESS == err)
  {
    cout << "Device was initially timestamped on: ";
    timeinfo = localtime (&initialTime);
    cout << asctime(timeinfo) << endl;
  }
  else
  {
    cout << "Error(" << err << ") in function getInitialTime: " << GetErrorStringA(err) << endl;
  }
  //! [Calling getInitialTime]

  //
  // The below functions are only supported on the XL platform.
  //
  {
    //! [Calling getDeviceSerial2]
    char serial[21];
    err = Smart_getDeviceSerial2 (pSmart, serial, sizeof(serial));
    if (ERR_SUCCESS == err)
    {
      cout << "Device serial number: " << serial << endl;
    }
    else if (ERR_NOT_SUPPORTED == err)
    {
      cout << "Smart_getDeviceSerial2 is not supported on this platform" << endl;
    }
    else
    {
      cout << "Error(" << err << ") in function getDeviceSerial: " << GetErrorStringA(err) << endl;
    }
    //! [Calling getDeviceSerial2]

    //! [Calling getRemainingLifeTime2]
    unsigned char life;
    err = Smart_getRemainingLifeTime2 (pSmart, &life);
    if (ERR_SUCCESS == err)
    {
      cout << "Estimated remaining lifetime: " << (int)life << "%" << endl;
    }
    else if (ERR_NOT_SUPPORTED == err)
    {
      cout << "Smart_getRemainingLifeTime2 is not supported on this platform" << endl;
    }
    else
    {
      cout << "Error(" << err << ") in function getRemainingLifeTime: " << GetErrorStringA(err) << endl;
    }
    //! [Calling getRemainingLifeTime2]

    //! [Calling getInitialTime2]
    time_t initialTime;
    struct tm * timeinfo;
    err = Smart_getInitialTime2 (pSmart, &initialTime);
    if (ERR_SUCCESS == err)
    {
      cout << "Device was initially timestamped on: ";
      timeinfo = localtime (&initialTime);
      cout << asctime(timeinfo) << endl;
    }
    else if (ERR_NOT_SUPPORTED == err)
    {
      cout << "Smart_getInitialTime2 is not supported on this platform" << endl;
    }
    else
    {
      cout << "Error(" << err << ") in function getInitialTime: " << GetErrorStringA(err) << endl;
    }
    //! [Calling getInitialTime2]
  }

}


int main(void)
{
  //! [Calling Release]
  //! [Calling GetSmart]
  SMARTHANDLE pSmart = ::GetSmart();
  assert(pSmart);

  show_card_data(pSmart);

  Smart_release(pSmart);
  //! [Calling GetSmart]
  //! [Calling Release]
}
