/* g++ -DLINUX examples/touchscreen_example.cpp  -lcc-aux -pthread -ldl */
#include <TouchScreen.h>
#include <CCAuxErrors.h>
#include <assert.h>
#include <iostream>

using namespace std;
using namespace CrossControl;

void touchscreen_example(TOUCHSCREENHANDLE pTouchScreen)
{
  CrossControl::eErr err;
  unsigned short rightclicktime, debouncetime;
  TouchScreenModeSettings ts_mode;

  //! [Calling TouchScreen_getMode]
  err = TouchScreen_getMode(pTouchScreen, &ts_mode);
  if(err == ERR_SUCCESS)
  {
    switch(ts_mode)
    {
    case MOUSE_NEXT_BOOT: cout << "USB profile is set to Mouse profile (active next boot)" << endl; break; 
    case TOUCH_NEXT_BOOT: cout << "USB profile is set to Touch profile (active next boot)" << endl; break; 
    case MOUSE_NOW: cout << "USB profile is set to Mouse profile" << endl; break; 
    case TOUCH_NOW: cout << "USB profile is set to Touch profile" << endl; break; 
    default: cout << "Error: invalid setting returned from getMode" << endl; break; 
    }   
  } 
  else if (err == ERR_NOT_SUPPORTED) {
	  cout << "Function TouchScreen_getMode() is not supported on this platform" << endl;
  }
  else 
  {
    cout << "Error(" << err << ") in function getMode: " << GetErrorStringA(err) << endl;
  }
  //! [Calling TouchScreen_getMode]

  //! [Calling TouchScreen_getMouseRightClickTime]
  err = TouchScreen_getMouseRightClickTime(pTouchScreen, &rightclicktime);
  if(err == ERR_SUCCESS)
  {
    cout << "Right click time is set to: " << (int)rightclicktime << " ms" << endl;
  }
  else 
  {
    cout << "Error(" << err << ") in function getMouseRightClickTime: " << GetErrorStringA(err) << endl;
  }
  //! [Calling TouchScreen_getMouseRightClickTime]


  //! [Calling TouchScreen_getAdvancedSetting]
  err = TouchScreen_getAdvancedSetting(pTouchScreen, TS_DEBOUNCE_TIME, &debouncetime);
  if(err == ERR_SUCCESS)
  {
    cout << "Touchscreen debounce time is set to: " << (int)debouncetime  << " ms" << endl;
  }
  else 
  {
    cout << "Error(" << err << ") in function getAdvancedSetting: " << GetErrorStringA(err) << endl;
  }
  //! [Calling TouchScreen_getAdvancedSetting]
}


int main(void)
{
  //! [Calling TouchScreen_release]
  //! [Calling GetTouchScreen]
  TOUCHSCREENHANDLE pTouchScreen = ::GetTouchScreen();
  assert(pTouchScreen);

  touchscreen_example(pTouchScreen);

  TouchScreen_release(pTouchScreen);
  //! [Calling GetTouchScreen]
  //! [Calling TouchScreen_release]
}
