﻿using System;
using System.Windows.Forms;
using CrossControl;
using System.Drawing;
using Video_exampleCS;

namespace XmVideo
{
    public partial class Form1 : Form
    {
        CCAuxErrorCS.eErr err;
        CCVideoCS VideoCtrl = new CCVideoCS();
        bool initDone = false;

        public Form1()
        {
  
            InitializeComponent();

            try
            {
                err = VideoCtrl.init(1);
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("init", err);
                }
                
                err = VideoCtrl.setActiveChannel(CCVideoCS.VideoChannel.Analog_Channel_1);
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("setActiveChannel", err);
                }

                err = VideoCtrl.setColorKeys(0xFF, 0x0, 0xFF);  //Use pure colors
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("setColorKeys", err);
                }

                err = VideoCtrl.setVideoArea(0, 0, 720, 576);
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("setVideoArea", err);
                }

                err = VideoCtrl.setScaling(1, 1);
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("setScaling", err);
                }

                err = VideoCtrl.showVideo(true);
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("showVideo", err);
                }
            }
            catch (Exception e)
            {
                MessageBox.Show(e + "Exception caught.");
            }
            initDone = true;
        
        }

        
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            VideoCtrl.Dispose();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err;
            err = VideoCtrl.setActiveChannel(CCVideoCS.VideoChannel.Analog_Channel_1);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
            {
                showError("setActiveChannel", err);
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err;
            err = VideoCtrl.setActiveChannel(CCVideoCS.VideoChannel.Analog_Channel_2);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
            {
                showError("setActiveChannel", err);
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err;
            err = VideoCtrl.setActiveChannel(CCVideoCS.VideoChannel.Analog_Channel_3);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
            {
                showError("setActiveChannel", err);
            }
        }

        private void button3_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err;
            err = VideoCtrl.setActiveChannel(CCVideoCS.VideoChannel.Analog_Channel_4);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
            {
                showError("setActiveChannel", err);
            }
        }

        private void Form1_Move(object sender, EventArgs e)
        {
            if (!initDone)
            {
                return;
            }

            try
            {
                Point panelOrigin = new Point(0, 0);
                Point screenOrigin;
                UInt16 offsetX, offsetY;

                screenOrigin = VideoPanel.PointToScreen(panelOrigin);


                if (screenOrigin.X < 0)
                {
                    offsetX = 0;
                }
                else
                {
                    offsetX = Convert.ToUInt16(screenOrigin.X);
                }

                if (screenOrigin.Y < 0)
                {
                    offsetY = 0;
                }
                else
                {
                    offsetY = Convert.ToUInt16(screenOrigin.Y);
                }
                
                err = VideoCtrl.setVideoArea(offsetX, offsetY, Convert.ToUInt16(offsetX + 720), Convert.ToUInt16(offsetY + 576));
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                {
                    showError("setVideoArea", err);
                }
                

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex + "Exception caught.");
            }

        }

        /// <summary>
        /// Show error message.
        /// </summary>
        /// <param name="strFunctions">Function name</param>
        /// <param name="err">error status</param>
        /// <returns></returns>
        private void showError(string strFunctions, CCAuxErrorCS.eErr err)
        {
            Int16 errorNr;
            errorNr = Convert.ToInt16(err);
           
            MessageBox.Show("Error(" + errorNr.ToString() + ") in function " + strFunctions + ": " + CCAuxErrorCS.GetErrorString(err));

        }

        private void buttonSnapshot_Click(object sender, EventArgs e)
        {
            new SnapshotForm(VideoCtrl).ShowDialog();
        }

    }
}
