using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using CrossControl;
using System.Runtime.InteropServices;
using System.IO;
using System.Threading;

namespace Video_exampleCS
{
    public partial class SnapshotForm : Form
    {
        CCVideoCS VideoCtrl;
        public SnapshotForm(CCVideoCS video)
        {
            InitializeComponent();
            VideoCtrl = video;
        }



        private void buttonSnapshot_Click(object sender, EventArgs e)
        {
            string filename = @"c:\snapshotcs_ni.bmp";
            CCAuxErrorCS.eErr err = VideoCtrl.takeSnapshot(filename.ToCharArray(), false);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
            {
                showError("snapshot non-interlaced", err);
                return;
            }

            using (Bitmap bmp = new Bitmap(filename))
            {
                Graphics graph = CreateGraphics();
                graph.DrawImage(bmp, 10, 12);
            }

            MessageBox.Show("non-interlaced image.");

            filename = @"c:\snapshotcs_i.bmp";
            err = VideoCtrl.takeSnapshot(filename.ToCharArray(), true);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
            {
                showError("snapshot interlaced", err);
                return;
            }

            using (Bitmap bmp = new Bitmap(filename))
            {
                Graphics graph = CreateGraphics();
                graph.DrawImage(bmp, 10, 12);
            }
            MessageBox.Show("interlaced image.");
        }

        private void buttonSsRaw_Click(object sender, EventArgs e)
        {
            IntPtr unmanagedPointer = Marshal.AllocHGlobal(2000000);

            CCAuxErrorCS.eErr err = VideoCtrl.takeSnapshotRaw(unmanagedPointer, 2000000, false);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
                showError("snapshotRaw non-interlaced", err);

            err = VideoCtrl.takeSnapshotRaw(unmanagedPointer, 2000000, true);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
                showError("snapshotRaw interlaced", err);

            Marshal.FreeHGlobal(unmanagedPointer);
        }

        private void showBitmap(byte[] bitmapBuffer)
        {
            MemoryStream memoryStream = new MemoryStream(bitmapBuffer);
            //make a new Bitmap object the owner of the MemoryStream

            Bitmap bmp = new Bitmap(memoryStream);
            Graphics graph = CreateGraphics();
            graph.DrawImage(bmp, 10, 12);
        }

        private void buttonSsBmp_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err;

            err = VideoCtrl.activateSnapshot(true);
            if (CCAuxErrorCS.eErr.SUCCESS != err)
            {
                MessageBox.Show("Failed to activate snapshot. Error: " + CCAuxErrorCS.GetErrorString(err));
                return;
            }
            // activation takes up to 40ms
            Thread.Sleep(40);

            CrossControl.CCVideoCS.videoStandard standard;
            err = VideoCtrl.getVideoStandard(out standard);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
                MessageBox.Show("Failed to get video standard. Error: " + CCAuxErrorCS.GetErrorString(err));
            else
            {
                bool ntsc = false;
                if (
                    (CCVideoCS.videoStandard.STD_M_J_NTSC == standard)
                    || (CCVideoCS.videoStandard.STD_NTSC == standard))
                    ntsc = true;

                byte[] bmpBuffer;

                err = VideoCtrl.takeSnapshotBmp(out bmpBuffer, false, ntsc);
                if (CCAuxErrorCS.eErr.SUCCESS == err)
                {
                    showBitmap(bmpBuffer);                    
                    MessageBox.Show("snapshotBmp non-interlaced.");
                }
                else
                    MessageBox.Show("snapshotBmp non-interlaced failed. Error: " + CCAuxErrorCS.GetErrorString(err));


                err = VideoCtrl.takeSnapshotBmp(out bmpBuffer, true, ntsc);
                if (CCAuxErrorCS.eErr.SUCCESS == err)
                {
                    showBitmap(bmpBuffer);
                    MessageBox.Show("snapshotBmp interlaced.");
                }
                else
                    MessageBox.Show("snapshotBmp interlaced failed. Error: " + CCAuxErrorCS.GetErrorString(err));
            }
        }

        private void buttonCreateBmp_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err;

            err = VideoCtrl.activateSnapshot(true);
            if (CCAuxErrorCS.eErr.SUCCESS != err)
            {
                MessageBox.Show("Failed to activate snapshot. Error: " + CCAuxErrorCS.GetErrorString(err));
                return;
            }
            // activation takes up to 40ms
            Thread.Sleep(40);

            CrossControl.CCVideoCS.videoStandard standard;
            err = VideoCtrl.getVideoStandard(out standard);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
                MessageBox.Show("Failed to get video standard. Error: " + CCAuxErrorCS.GetErrorString(err));
            else
            {
                bool ntsc = false;
                if (
                    (CCVideoCS.videoStandard.STD_M_J_NTSC == standard)
                    || (CCVideoCS.videoStandard.STD_NTSC == standard))
                    ntsc = true;

                // allocate an IntPtr big enough to hold a raw snapshot (2M)
                IntPtr unmanagedPointer = Marshal.AllocHGlobal(2000000);

                err = VideoCtrl.takeSnapshotRaw(unmanagedPointer, 2000000, false);
                if (err != CCAuxErrorCS.eErr.SUCCESS)
                    showError("takeSnapshotRaw non-interlaced", err);
                else
                {
                    byte[] bmpBuffer;

                    err = VideoCtrl.createBitmap(out bmpBuffer, unmanagedPointer, 2000000, false, ntsc);
                    if (CCAuxErrorCS.eErr.SUCCESS == err)
                    {
                        showBitmap(bmpBuffer);
                        MessageBox.Show("createBitmap non-interlaced.");
                    }
                    else
                        MessageBox.Show("createBitmap non-interlaced failed. Error: " + CCAuxErrorCS.GetErrorString(err));

                    err = VideoCtrl.takeSnapshotRaw(unmanagedPointer, 2000000, true);
                    if (err != CCAuxErrorCS.eErr.SUCCESS)
                        showError("takeSnapshotRaw interlaced", err);
                    else
                    {
                        err = VideoCtrl.createBitmap(out bmpBuffer, unmanagedPointer, 2000000, true, ntsc);
                        if (CCAuxErrorCS.eErr.SUCCESS == err)
                        {
                            showBitmap(bmpBuffer);
                            MessageBox.Show("createBitmap interlaced.");
                        }
                        else
                            MessageBox.Show("createBitmap interlaced failed. Error: " + CCAuxErrorCS.GetErrorString(err));
                    }
                }
                Marshal.FreeHGlobal(unmanagedPointer);
            }
        }

        private void buttonActivateSnapshot_Click(object sender, EventArgs e)
        {
            CCAuxErrorCS.eErr err = VideoCtrl.activateSnapshot(true);
            if (err != CCAuxErrorCS.eErr.SUCCESS)
                showError("activateSnapshot", err);
        }

        private void showError(string strFunctions, CCAuxErrorCS.eErr err)
        {
            Int16 errorNr;
            errorNr = Convert.ToInt16(err);

            MessageBox.Show("Error(" + errorNr.ToString() + ") in function " + strFunctions + ": " + CCAuxErrorCS.GetErrorString(err));

        }

        private void button1_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.OK;
        }

    }
}