/************************************************
*
*  CROSSCONTROL AUX API
*
*  CCAuxTypes.h
*
*  Version 2.7.2.0, 2014-08-25
*
*  (c) maximatecc 2013
*
*  File description: Common types
*
************************************************/

#ifndef CCAUXTYPES_H_
#define CCAUXTYPES_H_

#ifdef __cplusplus
namespace CrossControl
{
#endif

#ifndef __cplusplus
#define bool int
#endif

  
/*!
* Voltage type enumeration
*/
enum VoltageEnum
{
  VOLTAGE_24VIN = 0, /*! < 24VIN            */
  VOLTAGE_24V,       /*! < 24V              */
  VOLTAGE_12V,       /*! < 12V              */
  VOLTAGE_12VID,     /*! < 12VID            */
  VOLTAGE_5V,        /*! < 5V               */
  VOLTAGE_3V3,       /*! < 3.3V             */
  VOLTAGE_VTFT,      /*! < VTFT             */
  VOLTAGE_5VSTB,     /*! < 5VSTB            */
  VOLTAGE_1V9,       /*! < 1.9V             */
  VOLTAGE_1V8,       /*! < 1.8V             */
  VOLTAGE_1V5,       /*! < 1.5V             */
  VOLTAGE_1V2,       /*! < 1.2V             */
  VOLTAGE_1V05,      /*! < 1.05V            */
  VOLTAGE_1V0,       /*! < 1.0V             */
  VOLTAGE_0V9,       /*! < 0.9V             */
  VOLTAGE_VREF_INT,  /*! < SS internal VRef */
  VOLTAGE_24V_BACKUP,/*! < 24V backup capacitor */
  VOLTAGE_2V5,       /*! < 2.5V             */
  VOLTAGE_1V1,       /*! < 1.1V             */
  VOLTAGE_1V3_PER,   /*! < 1.3V_PER         */
  VOLTAGE_1V3_VDDA,  /*! < 1.3V_VDDA        */
  VOLTAGE_3V3STBY,   /*! < 3.3V STBY VC     */
  VOLTAGE_VPMIC,     /*! < V PMIC VC        */
  VOLTAGE_VMAIN      /*! < V MAIN VC        */
};

/*! Light sensor operation ranges.*/
typedef enum
{
  RangeStandard = 0, /*! Light sensor operation range standard */
  RangeExtended = 1  /*! Light sensor operation range extended */
} LightSensorOperationRange;

/*! Light sensor sampling modes.*/
typedef enum
{
  SamplingModeStandard = 0, /*! Standard sampling mode.*/
  SamplingModeExtended,     /*!Extended sampling mode.*/
  SamplingModeAuto         /*! Auto switch between standard and extended
                 sampling mode depending on saturation.*/
} LightSensorSamplingMode;

/*!
* Enable/disable enumeration
*/
typedef enum
{
  Disabled = 0, /*! The setting is disabled or turned off */
  Enabled = 1   /*! The setting is enabled or turned on */
} CCStatus;

/*!
* Error code enumeration
*/
typedef enum
{
  ERR_SUCCESS = 0,                        /*! Success                        */
  ERR_OPEN_FAILED = 1,                    /*! Open failed                    */
  ERR_NOT_SUPPORTED = 2,                  /*! Not supported                  */
  ERR_UNKNOWN_FEATURE = 3,                /*! Unknown feature                */
  ERR_DATATYPE_MISMATCH = 4,              /*! Datatype mismatch              */
  ERR_CODE_NOT_EXIST = 5,                 /*! Code doesn't exist             */
  ERR_BUFFER_SIZE = 6,                    /*! Buffer size error              */
  ERR_IOCTRL_FAILED = 7,                  /*! IoCtrl operation failed        */
  ERR_INVALID_DATA = 8,                   /*! Invalid data                   */
  ERR_INVALID_PARAMETER = 9,              /*! Invalid parameter              */
  ERR_CREATE_THREAD = 10,                 /*! Failed to create thread        */
  ERR_IN_PROGRESS = 11,                   /*! Operation in progress          */
  ERR_CHECKSUM = 12,                      /*! Checksum error                 */
  ERR_INIT_FAILED = 13,                   /*! Initalization failed           */
  ERR_VERIFY_FAILED = 14,                 /*! Failed to verify               */
  ERR_DEVICE_READ_DATA_FAILED = 15,       /*! Failed to read from device     */
  ERR_DEVICE_WRITE_DATA_FAILED = 16,      /*! Failed to write to device      */
  ERR_COMMAND_FAILED = 17,                /*! Command failed                 */
  ERR_EEPROM = 18,                        /*! Error in EEPROM memory         */
  ERR_JIDA_TEMP = 19,                     /*! Failed to get JIDA temperature */
  ERR_AVERAGE_CALC_STARTED = 20,          /*! Calculation already started    */
  ERR_NOT_RUNNING = 21,                   /*! Thread isn't running           */
  ERR_I2C_EXPANDER_READ_FAILED = 22,      /*! I2C read failure               */
  ERR_I2C_EXPANDER_WRITE_FAILED = 23,     /*! I2C write failure              */
  ERR_I2C_EXPANDER_INIT_FAILED = 24,      /*! I2C initialization failure     */
  ERR_NEWER_SS_VERSION_REQUIRED = 25,     /*! SS version too old             */
  ERR_NEWER_FPGA_VERSION_REQUIRED = 26,   /*! FPGA version too old           */
  ERR_NEWER_FRONT_VERSION_REQUIRED = 27,  /*! FRONT version too old          */
  ERR_TELEMATICS_GPRS_NOT_AVAILABLE = 28, /*! GPRS module not available      */
  ERR_TELEMATICS_WLAN_NOT_AVAILABLE = 29, /*! WLAN module not available      */
  ERR_TELEMATICS_BT_NOT_AVAILABLE = 30,   /*! Bluetooth module not available */
  ERR_TELEMATICS_GPS_NOT_AVAILABLE = 31,  /*! GPS module not available       */
  ERR_MEM_ALLOC_FAIL = 32,                /*! Failed to allocate memory      */
  ERR_JOIN_THREAD = 33                    /*! Failed to join thread          */
} eErr;


enum DeInterlaceMode
{
  DeInterlace_Even = 0, /*! Use only even rows from the interlaced input stream */
  DeInterlace_Odd = 1, /*! Use only odd rows from the interlaced input stream */
  DeInterlace_BOB = 2 /*! Use alternating odd and even rows from the interlaced input stream */
};

/*!
* The available analog video channels
*/
enum VideoChannel
{
  Analog_Channel_1 = 0, /* Analog video channel 1 */
  Analog_Channel_2 = 1, /* Analog video channel 2 */
  Analog_Channel_3 = 2, /* Analog video channel 3 */
  Analog_Channel_4 = 3  /* Analog video channel 4 */
};


/* Struct used for received video */
struct received_video
{
  unsigned short received_width;
  unsigned short received_height;
  unsigned char received_framerate;
};

/* Struct used for I2c-accesses to decoder */
struct video_dec_command
{
  unsigned char decoder_register;
  unsigned char register_value;
};


/* Version info struct */
struct version_info
{
  unsigned char major;   /*!< version major number */
  unsigned char minor;   /*!< version minor number */
  unsigned char release; /*!< version release number */
  unsigned char build;   /*!< version build number */
};

/* Video standard */
/* The video decoder auto detect the video standard */
typedef enum
{
  STD_M_J_NTSC = 0,         /*! (M,J) NTSC ITU-R BT.601 */
  STD_B_D_G_H_I_N_PAL = 1,  /*! (B, D, G, H, I, N) PAL ITU-R BT.601 */
  STD_M_PAL = 2,            /*! (M) PAL ITU-R BT.601 */
  STD_PAL = 3,              /*! PAL-Nc ITU-R BT.601 */
  STD_NTSC = 4,             /*! NTSC 4.43 ITU-R BT.601 */
  STD_SECAM = 5             /*! SECAM ITU-R BT.601 */
} videoStandard;

enum VideoRotation
{
  RotNone = 0,
  Rot90,
  Rot180,
  Rot270
};

typedef struct version_info VersionType;

/* Buzzer setup struct */
typedef struct
{
  unsigned short frequency; /*!< buzzer frequency*/
  unsigned short volume; /*!< buzzer volume*/
} BuzzerSetup;

/* Led timing setup struct */
typedef struct
{
  unsigned char onTime; /*!< LED on time in 10ms*/
  unsigned char offTime; /*!< LED off time in 10ms*/
  unsigned char idleTime; /*!< LED idle time in 100ms*/
  unsigned char nrOfPulses; /*!< Pulses per sequences*/
} LedTimingType;

/* For FPGA leds */
typedef struct
{
  unsigned char ledNbr; /*!< Number of LED*/
  unsigned char onTime; /*!< LED on time in 10ms*/
  unsigned char offTime; /*!< LED off time in 10ms*/
  unsigned char idleTime; /*!< LED idle time in 100ms*/
  unsigned char nrOfPulses; /*!< Pulses per sequences*/
} FpgaLedTimingType;

/* Led color struct */
typedef struct
{
  unsigned char red; /*!< Red color intensity 0-0x0F*/
  unsigned char green; /*!< Green color intensity 0-0x0F*/
  unsigned char blue; /*!< Blue color intensity 0-0x0F*/
} LedColorMixType;

/*!
* Can frame type settings
*/
typedef enum
{
  FrameStandard,
  FrameExtended,
  FrameStandardExtended
} CanFrameType;

/*!
* Trigger configuration enumeration. Valid settings for enabling of front button and external on/off signal.
* For platforms XM, XL and XA platforms, front button and on/off (ignition) signal can be configured. 
* For the VC platform, CI state activity and Can data reception can also be used as wakeup sources from suspend mode.
* bit 0 - enable wakeup by front button (from OFF and suspend mode)
* bit 1 - enable wakeup by on/off (ignition) signal (from OFF and suspend mode)
* bit 2 - enable wakeup by CAN activity (from suspend mode, VC only)
* bit 3 - enable wakeup by CI (Configurabe input) state change (from suspend mode, VC only)
*/
typedef enum
{
  Front_Button_Enabled = 1,           /*!< Front button is enabled for startup and wake-up */
  OnOff_Signal_Enabled = 2,           /*!< The external on/off signal is enabled for startup and wake-up */
  Both_Button_And_Signal_Enabled = 3, /*!< Both of the above are enabled */
  CAN_Activity = 4,                   /*!< VC platform, wake up on CAN only */
  CAN_Button_Activity = 5,            /*!< VC platform, wake up on CAN and Buttons */
  CAN_OnOff_Activity = 6,             /*!< VC platform, wake up on CAN and On/Off/Ignition signal */
  CAN_Button_OnOff_Activity = 7,      /*!< VC platform, wake up on CAN, Buttons and On/Off/Ignition signal */
  CI_State_Activity = 8,              /*!< VC platform, wake up on Configurable Input State Change */
  CI_Button_Activity = 9,             /*!< VC platform, wake up on CI and Button State Change */
  CI_OnOff_Activity = 10,             /*!< VC platform, wake up on CI and OnOff Signal State Change */
  CI_Button_OnOff_Activity = 11,      /*!< VC platform, wake up on CI, Button and OnOff Signal State Change */
  CI_CAN_Activity = 12,               /*!< VC platform, wake up on CI and CAN State Change */
  CI_CAN_Button_Activity = 13,        /*!< VC platform, wake up on CI, CAN and Button State Change */
  CI_CAN_OnOff_Activity = 14,         /*!< VC platform, wake up on CI, CAN and OnOff Signal State Change */
  All_Events = 15,                    /*!< VC platform, wake up on all events */
  Last_trigger_conf
} TriggerConf;

/*!
* Button and on/off signal actions.
*/
typedef enum
{
  NoAction = 0, /*!< No action taken */
  ActionSuspend = 1, /*!< The system enters suspend mode */
  ActionShutDown = 2 /*!< The system shuts down */
} PowerAction;

/*!
* Current status for front panel button and on/off signal. If any of them generate a suspend or shutdown event, it may also be read, briefly.
* When the button/signal is released, typically BPTS_Suspend or BPTS_ShutDown follows.
* Note: Do not rely on getting BPTS_ShutDown or BPTS_Suspend from user applications. The system is likely to start shutting down before the status can be read.
* Instead, use the PowerMgr class for handling system shutdown/suspend events.
*/
typedef enum
{
  BPTS_No_Change    = 0,  /*!< No change */
  BPTS_ShutDown    = 1,  /*!< A shutdown has been initiated since the front panel button has been pressed longer than the set FrontBtnShutDownTrigTime */
  BPTS_Suspend    = 2,  /*!< Suspend mode has been initiated since the front panel button has been pressed (shortly) and suspend mode is enabled */
  BPTS_Restart    = 3,  /*!< Not currently in use */
  BPTS_BtnPressed    = 4,  /*!< The front panel button is currently pressed. It has not been released and it has not yet been held longer than FrontBtnShutDownTrigTime. */
  BPTS_BtnPressedLong = 5,  /*!< The front panel button is currently pressed. It has not been released and it has been held longer than FrontBtnShutDownTrigTime. */
  BPTS_SignalOff    = 6  /*!< The external on/off signal is low, but not yet long enough for the ExtOnOffSigSuspTrigTime. */
} ButtonPowerTransitionStatus;

/*!
* Overcurrent detection status.
*/
typedef enum
{
  OCD_OK = 0,       /*!< Normal operation, no overcurrent condition detected */
  OCD_OC = 1,       /*!< Overcurrent has been detected, power has therefore been turned off, but may be functioning again if the problem disappeared after re-test*/
  OCD_POWER_OFF = 2 /*!< Overcurrent has been detected, power has been permanently turned off */
} OCDStatus;

/*!
* Diagnostic timer data
*/
struct TimerType
{
  unsigned long TotRunTime; /*! Total running time (minutes)*/
  unsigned long TotSuspTime; /*! Total suspend time (minutes)*/
  unsigned long TotHeatTime; /*! Total heating time (minutes)*/
  unsigned long RunTime40_60; /*! Total runtime in 40-60deg (minutes)*/
  unsigned long RunTime60_70; /*! Total runtime in 60-70deg (minutes)*/
  unsigned long RunTime70_80; /*! Total runtime in 70-80deg (minutes)*/
  unsigned long Above80RunTime;/*! Total runtime above 80deg (minutes)*/
};

/*!
* Jida temperature sensor types
*/
enum JidaSensorType
{
  TEMP_CPU = 0,
  TEMP_BOX = 1,
  TEMP_ENV = 2,
  TEMP_BOARD = 3,
  TEMP_BACKPLANE = 4,
  TEMP_CHIPSETS = 5,
  TEMP_VIDEO = 6,
  TEMP_OTHER = 7
};


/*!
* Upgrade Action enumeration
*/
enum UpgradeAction
{
  UPGRADE_INIT,         /*! Initiating, checking for compatibility etc */
  UPGRADE_PREP_COM,       /*! Preparing communication */
  UPGRADE_READING_FILE,     /*! Opening and reading the supplied file */
  UPGRADE_CONVERTING_FILE,    /*! Converting the mcs format to binary format */
  UPGRADE_FLASHING,       /*! Flashing the file */
  UPGRADE_VERIFYING,        /*! Verifying the programmed image */
  UPGRADE_COMPLETE,       /*! Upgrade was finished */
  UPGRADE_COMPLETE_WITH_ERRORS  /*! Upgrade finished prematurely, see errorCode for the reason of failure */
};

/*!
* Upgrade Status
*/
struct UpgradeStatus
{
  enum UpgradeAction currentAction; /*! The current action. */
  unsigned char percent; /*! Represents the percentage of completion of the current action */
  eErr errorCode; /*! The status of the operation */
};

/*!
* Enumeration of standard colors
*/
typedef enum
{
  RED = 0,     /*! RGB 0xF, 0x0, 0x0*/
  GREEN,       /*! RGB 0x0, 0xF, 0x0*/
  BLUE,        /*! RGB 0x0, 0x0, 0xF*/
  CYAN,        /*! RGB 0x0, 0xF, 0xF*/
  MAGENTA,     /*! RGB 0xF, 0x0, 0xF*/
  YELLOW,      /*! RGB 0xF, 0xF, 0x0*/
  UNDEFINED_COLOR   /*! Returns if color is not a standard color*/
} CCAuxColor;

/*!
* Enumeration of RS4XX ports (1-4)
*/
typedef enum
{
  RS4XXPort1 = 1,
  RS4XXPort2,
  RS4XXPort3,
  RS4XXPort4
} RS4XXPort;

/*!
* Enumeration of ConfigurableInput modes
*/
typedef enum
{
    CFGIN_NOT_IN_USE = 0,   /*! Disable configurable input measurement */
    CFGIN_HI_SWITCH,        /*! Read digital input value with waitForCfgInValue */
    CFGIN_LOW_SWITCH,       /*! Read digital input value with waitForCfgInValue */
    CFGIN_VOLTAGE_3V3,      /*! Read voltage input value with waitForCfgInValue */
    CFGIN_VOLTAGE_5VPD,     /*! Read voltage input value with waitForCfgInValue */
    CFGIN_RESISTANCE,       /*! Read resistance input value with waitForCfgInValue */
    CFGIN_FREQ_FLOATING,    /*! Read frequency value with waitForCfgInFrequency */
    CFGIN_FREQ_PULLUP,      /*! Read frequency value with waitForCfgInFrequency */
    CFGIN_FREQ_PULLDOWN     /*! Read frequency value with waitForCfgInFrequency */
} CfgInModeEnum;

/*!
* Enumeration of Buffon Configuration (bitfield representation)
*/
typedef enum
{
    BUTTON_ONLY_MP_ACTION = 0x00,                  /*! Buttons are only read by Main Processor, i.e. normal button action which is handled in application space */
    BUTTON_AS_STARTUP_TRIG = 0x02,                 /*! Set button to be used as startup trigger, in addition to MP application event */
    BUTTON_AS_ACTION_TRIG = 0x04,                  /*! Set button to trigger suspend, shutdown or hard shutdown actions */
    BUTTON_AS_ACTION_STARTUP_TRIG = 0x06,          /*! Set button to trigger startup, suspend, shutdown or hard shutdown actions */
    BUTTON_AS_BACKLIGHT_DECREASE = 0x08,           /*! Set button to act as backlight decrease button */
    BUTTON_AS_BACKLIGHT_DECR_STARTUP_TRIG = 0x0A,  /*! Set button to act as backlight decreaste and startup trigger */
    BUTTON_AS_BACKLIGHT_INCREASE = 0x0C,           /*! Set button to act as backlight increase button */
    BUTTON_AS_BACKLIGHT_INCR_STARTUP_TRIG = 0x0E   /*! Set button to act as backlight increase button and startup trigger */
} ButtonConfigEnum;


#ifdef __cplusplus
}
#endif

#endif /*CCAUXTYPES_H_*/

