/************************************************
*
*  CROSSCONTROL AUX API
*
*  DiagnosticCodes.h
*
*  Version 2.7.2.0, 2014-08-25
*
*  (c) maximatecc 2013
*
*  File description: Diagnostic code handling
*  String access functions for codes used in the diagnostic functions
*
************************************************/

#ifndef CC_DIAGCODES_H_
#define CC_DIAGCODES_H_

#include "CCPlatform.h"
#include "CCAuxTypes.h"

#ifdef __cplusplus
namespace CrossControl
{
#endif

  /*! The restart codes returned by getStartupReason. */
  enum startupReasonCodes
  {
    startupReasonCodeUndefined  =  0x0000,    /*! Unknown startup reason. */
    startupReasonCodeButtonPress = 0x0055,    /*! The system was started by front panel button press */
    startupReasonCodeExtCtrl = 0x00AA,      /*! The system was started by the external control signal */
    startupReasonCodeMPRestart = 0x00F0,    /*! The system was restarted by OS request */
    startupReasonCodePowerOnStartup  = 0x000F,  /*! The system was started due to the PowerOnStartup setting */
    startupReasonCodeCanActivity  = 0x003c,  /*! The system was started due to activity on the Can bus (CCpilot VC family) */
    startupReasonCodeCIActivity  = 0x00c3  /*! The system was started due to activity on the configurable input signals (CCpilot VC family) */
  };

  /*! The shutdown codes returned by getShutDownReason. */
  enum shutDownReasonCodes
  {
    shutdownReasonCodeNoError = 0x001F /*! No Error. Other values indicate that the system was shut down due to a serious error */
  };

  /*! The error codes returned by getHWErrorStatus. */
  enum hwErrorStatusCodes
  {
    errCodeNoErr = 0 /*! No Error. Other values indicate that the system has some hw errors */
  };
 
  /*!
  * Get a string description of an error code returned from getHwErrorStatus.
  * @param errCode An error code for which to get a string description.
  * @return String description of an error code.
  */
  EXTERN_C
    CCAUXDLL_API
    char const*
    CCAUXDLL_CALLING_CONV
    GetHwErrorStatusStringA(unsigned short errCode);

  /*!
  * Get a string description of an error code returned from getHwErrorStatus.
  * @param errCode An error code for which to get a string description.
  * @return String description of an error code.
  */
  EXTERN_C
    CCAUXDLL_API
    wchar_t const*
    CCAUXDLL_CALLING_CONV
    GetHwErrorStatusStringW(unsigned short errCode);

  /*!
  * Get a string description of a startup reason code returned from getStartupReason.
  * @param code A code for which to get a string description.
  * @return String description of a code.
  */
  EXTERN_C
    CCAUXDLL_API
    char const*
    CCAUXDLL_CALLING_CONV
    GetStartupReasonStringA(unsigned short code);

  /*!
  * Get a string description of a startup reason code returned from getStartupReason.
  * @param code A code for which to get a string description.
  * @return String description of a code.
  */
  EXTERN_C
    CCAUXDLL_API
    wchar_t const*
    CCAUXDLL_CALLING_CONV
    GetStartupReasonStringW(unsigned short code);

#ifdef __cplusplus
}
#endif

#endif /* CC_DIAGCODES_H_ */






